@@ -9,8 +9,9 @@ __all__ = (
     "Proxy",
 )
 
-from .version import version as __version__
 from .array_mapper import ArrayMapper
+from .indexers import (CombinatorialIndexer, Proxy, RandomIndexer,
+                       SequentialIndexer)
 from .mapped_matrix import MappedMatrix
 from .resource_group import ResourceGroup
-from .indexers import RandomIndexer, SequentialIndexer, CombinatorialIndexer, Proxy
+from .version import version as __version__
