@@ -1,11 +1,13 @@
-from .array_mapper import ArrayMapper
-from .indexers import RandomIndexer, SequentialIndexer, CombinatorialIndexer
-from .resource_group import ResourceGroup
-from .utils import filter_groups_for_packages, safe_concatenate_indices
+from typing import Any, Callable, Sequence, Union
+
+import numpy as np
 from bw_processing import Datapackage
 from scipy import sparse
-from typing import Union, Sequence, Any, Callable
-import numpy as np
+
+from .array_mapper import ArrayMapper
+from .indexers import CombinatorialIndexer, RandomIndexer, SequentialIndexer
+from .resource_group import ResourceGroup
+from .utils import filter_groups_for_packages, safe_concatenate_indices
 
 
 class MappedMatrix:
@@ -45,6 +47,7 @@ class MappedMatrix:
         seed_override: Union[int, None] = None,
         indexer_override: Any = None,
         diagonal: bool = False,
+        transpose: bool = False,
         custom_filter: Union[Callable, None] = None,
         empty_ok: bool = False,
     ):
@@ -59,6 +62,7 @@ class MappedMatrix:
                     use_distributions=use_distributions,
                     seed_override=seed_override,
                     custom_filter=custom_filter,
+                    transpose=transpose,
                 )
                 for group_label, filtered_package in lst
             ]
